@@ -30,7 +30,7 @@
 /* N32 ABI */
 #define __SCMP_NR_BASE	6000
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux 4.5-rc4 */
 const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", (__SCMP_NR_BASE + 22) },
@@ -126,7 +126,6 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "get_mempolicy", (__SCMP_NR_BASE + 232) },
 	{ "get_robust_list", (__SCMP_NR_BASE + 273) },
 	{ "get_thread_area", __PNR_get_thread_area },
-	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", (__SCMP_NR_BASE + 275) },
 	{ "getcwd", (__SCMP_NR_BASE + 77) },
 	{ "getdents", (__SCMP_NR_BASE + 76) },
@@ -259,15 +258,11 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "pipe", (__SCMP_NR_BASE + 21) },
 	{ "pipe2", (__SCMP_NR_BASE + 291) },
 	{ "pivot_root", (__SCMP_NR_BASE + 151) },
-	{ "pkey_alloc", (__SCMP_NR_BASE + 328) },
-	{ "pkey_free", (__SCMP_NR_BASE + 329) },
-	{ "pkey_mprotect", (__SCMP_NR_BASE + 327) },
 	{ "poll", (__SCMP_NR_BASE + 7) },
 	{ "ppoll", (__SCMP_NR_BASE + 265) },
 	{ "prctl", (__SCMP_NR_BASE + 153) },
 	{ "pread64", (__SCMP_NR_BASE + 16) },
 	{ "preadv", (__SCMP_NR_BASE + 293) },
-	{ "preadv2", (__SCMP_NR_BASE + 325) },
 	{ "prlimit64", (__SCMP_NR_BASE + 302) },
 	{ "process_vm_readv", (__SCMP_NR_BASE + 309) },
 	{ "process_vm_writev", (__SCMP_NR_BASE + 310) },
@@ -278,7 +273,6 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "putpmsg", (__SCMP_NR_BASE + 175) },
 	{ "pwrite64", (__SCMP_NR_BASE + 17) },
 	{ "pwritev", (__SCMP_NR_BASE + 294) },
-	{ "pwritev2", (__SCMP_NR_BASE + 326) },
 	{ "query_module", (__SCMP_NR_BASE + 171) },
 	{ "quotactl", (__SCMP_NR_BASE + 172) },
 	{ "read", (__SCMP_NR_BASE + 0) },
@@ -309,11 +303,9 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 126) },
 	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 295) },
 	{ "rtas", __PNR_rtas },
-	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
 	{ "s390_pci_mmio_read", __PNR_s390_pci_mmio_read },
 	{ "s390_pci_mmio_write", __PNR_s390_pci_mmio_write },
 	{ "s390_runtime_instr", __PNR_s390_runtime_instr },
-	{ "s390_sthyi", __PNR_s390_sthyi },
 	{ "sched_get_priority_max", (__SCMP_NR_BASE + 143) },
 	{ "sched_get_priority_min", (__SCMP_NR_BASE + 144) },
 	{ "sched_getaffinity", (__SCMP_NR_BASE + 196) },
@@ -399,7 +391,6 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "stat64", __PNR_stat64 },
 	{ "statfs", (__SCMP_NR_BASE + 134) },
 	{ "statfs64", (__SCMP_NR_BASE + 217) },
-	{ "statx", (__SCMP_NR_BASE + 330) },
 	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
@@ -514,15 +505,15 @@ const char *mips64n32_syscall_resolve_num(int num)
 }
 
 /**
- * Iterate through the syscall table and return the syscall mapping
+ * Iterate through the syscall table and return the syscall name
  * @param spot the offset into the syscall table
  *
- * Return the syscall mapping at position @spot or NULL on failure.  This
- * function should only ever be used internally by libseccomp.
+ * Return the syscall name at position @spot or NULL on failure.  This function
+ * should only ever be used internally by libseccomp.
  *
  */
-const struct arch_syscall_def *mips64n32_syscall_iterate(unsigned int spot)
+const char *mips64n32_syscall_iterate_name(unsigned int spot)
 {
 	/* XXX - no safety checks here */
-	return &mips64n32_syscall_table[spot];
+	return mips64n32_syscall_table[spot].name;
 }
