@@ -34,6 +34,6 @@ extern const struct arch_def arch_def_mipsel64n32;
 int mips64n32_syscall_resolve_name(const char *name);
 const char *mips64n32_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *mips64n32_syscall_iterate(unsigned int spot);
+const char *mips64n32_syscall_iterate_name(unsigned int spot);
 
 #endif
