@@ -34,6 +34,6 @@ extern const struct arch_def arch_def_ppc64le;
 int ppc64_syscall_resolve_name(const char *name);
 const char *ppc64_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *ppc64_syscall_iterate(unsigned int spot);
+const char *ppc64_syscall_iterate_name(unsigned int spot);
 
 #endif
