@@ -20,7 +20,7 @@ extern const struct arch_def arch_def_s390;
 int s390_syscall_resolve_name(const char *name);
 const char *s390_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *s390_syscall_iterate(unsigned int spot);
+const char *s390_syscall_iterate_name(unsigned int spot);
 
 int s390_syscall_rewrite(int *syscall);
 
