@@ -23,7 +23,7 @@ extern const struct arch_def arch_def_s390x;
 int s390x_syscall_resolve_name(const char *name);
 const char *s390x_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *s390x_syscall_iterate(unsigned int spot);
+const char *s390x_syscall_iterate_name(unsigned int spot);
 
 int s390x_syscall_rewrite(int *syscall);
 
