@@ -34,6 +34,6 @@ extern const struct arch_def arch_def_x32;
 int x32_syscall_resolve_name(const char *name);
 const char *x32_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *x32_syscall_iterate(unsigned int spot);
+const char *x32_syscall_iterate_name(unsigned int spot);
 
 #endif
