@@ -32,6 +32,6 @@ extern const struct arch_def arch_def_x86_64;
 int x86_64_syscall_resolve_name(const char *name);
 const char *x86_64_syscall_resolve_num(int num);
 
-const struct arch_syscall_def *x86_64_syscall_iterate(unsigned int spot);
+const char *x86_64_syscall_iterate_name(unsigned int spot);
 
 #endif
