@@ -381,6 +381,7 @@ static void _db_reset(struct db_filter *db)
 		r_iter = db->rules;
 		while (r_iter != NULL) {
 			db->rules = r_iter->next;
+			free(r_iter->args);
 			free(r_iter);
 			r_iter = db->rules;
 		}
@@ -511,29 +512,6 @@ static int _db_syscall_priority(struct db_filter *db,
 	return 0;
 }
 
-/**
- * Duplicate an existing filter rule
- * @param src the rule to duplicate
- *
- * This function makes an exact copy of the given rule, but does not add it
- * to any lists.  Returns a pointer to the new rule on success, NULL on
- * failure.
- *
- */
-struct db_api_rule_list *db_rule_dup(const struct db_api_rule_list *src)
-{
-	struct db_api_rule_list *dest;
-
-	dest = malloc(sizeof(*dest));
-	if (dest == NULL)
-		return NULL;
-	memcpy(dest, src, sizeof(*dest));
-	dest->prev = NULL;
-	dest->next = NULL;
-
-	return dest;
-}
-
 /**
  * Free and reset the seccomp filter collection
  * @param col the seccomp filter collection
@@ -570,7 +548,6 @@ int db_col_reset(struct db_filter_col *col, uint32_t def_action)
 	col->attr.act_badarch = SCMP_ACT_KILL;
 	col->attr.nnp_enable = 1;
 	col->attr.tsync_enable = 0;
-	col->attr.api_tskip = 0;
 
 	/* set the state */
 	col->state = _DB_STA_VALID;
@@ -795,9 +772,6 @@ int db_col_attr_get(const struct db_filter_col *col,
 	case SCMP_FLTATR_CTL_TSYNC:
 		*value = col->attr.tsync_enable;
 		break;
-	case SCMP_FLTATR_API_TSKIP:
-		*value = col->attr.api_tskip;
-		break;
 	default:
 		rc = -EEXIST;
 		break;
@@ -845,9 +819,6 @@ int db_col_attr_set(struct db_filter_col *col,
 			/* unsupported */
 			rc = -EOPNOTSUPP;
 		break;
-	case SCMP_FLTATR_API_TSKIP:
-		col->attr.api_tskip = (value ? 1 : 0);
-		break;
 	default:
 		rc = -EEXIST;
 		break;
@@ -1018,9 +989,10 @@ static void _db_node_mask_fixup(struct db_arg_chain_tree *node)
 static struct db_sys_list *_db_rule_gen_64(const struct arch_def *arch,
 					   uint32_t action,
 					   unsigned int syscall,
-					   const struct db_api_arg *chain)
+					   struct db_api_arg *chain)
 {
 	unsigned int iter;
+	int chain_len_max;
 	struct db_sys_list *s_new;
 	struct db_arg_chain_tree *c_iter_hi = NULL, *c_iter_lo = NULL;
 	struct db_arg_chain_tree *c_prev_hi = NULL, *c_prev_lo = NULL;
@@ -1033,7 +1005,10 @@ static struct db_sys_list *_db_rule_gen_64(const struct arch_def *arch,
 	s_new->num = syscall;
 	s_new->valid = true;
 	/* run through the argument chain */
-	for (iter = 0; iter < ARG_COUNT_MAX; iter++) {
+	chain_len_max = arch_arg_count_max(arch);
+	if (chain_len_max < 0)
+		goto gen_64_failure;
+	for (iter = 0; iter < chain_len_max; iter++) {
 		if (chain[iter].valid == 0)
 			continue;
 
@@ -1154,9 +1129,10 @@ gen_64_failure:
 static struct db_sys_list *_db_rule_gen_32(const struct arch_def *arch,
 					   uint32_t action,
 					   unsigned int syscall,
-					   const struct db_api_arg *chain)
+					   struct db_api_arg *chain)
 {
 	unsigned int iter;
+	int chain_len_max;
 	struct db_sys_list *s_new;
 	struct db_arg_chain_tree *c_iter = NULL, *c_prev = NULL;
 	bool tf_flag;
@@ -1168,7 +1144,10 @@ static struct db_sys_list *_db_rule_gen_32(const struct arch_def *arch,
 	s_new->num = syscall;
 	s_new->valid = true;
 	/* run through the argument chain */
-	for (iter = 0; iter < ARG_COUNT_MAX; iter++) {
+	chain_len_max = arch_arg_count_max(arch);
+	if (chain_len_max < 0)
+		goto gen_32_failure;
+	for (iter = 0; iter < chain_len_max; iter++) {
 		if (chain[iter].valid == 0)
 			continue;
 
@@ -1259,7 +1238,7 @@ int db_rule_add(struct db_filter *db, const struct db_api_rule_list *rule)
 	int rc = -ENOMEM;
 	int syscall = rule->syscall;
 	uint32_t action = rule->action;
-	const struct db_api_arg *chain = rule->args;
+	struct db_api_arg *chain = rule->args;
 	struct db_sys_list *s_new, *s_iter, *s_prev = NULL;
 	struct db_arg_chain_tree *c_iter = NULL, *c_prev = NULL;
 	struct db_arg_chain_tree *ec_iter;
@@ -1541,10 +1520,9 @@ int db_col_syscall_priority(struct db_filter_col *col,
 		if (rc_tmp < 0)
 			goto priority_failure;
 
-		/* if this is a pseudo syscall then we need to rewrite the
-		 * syscall for some arch specific reason, don't forget the
-		 * special handling for syscall -1 */
-		if (sc_tmp < -1) {
+		/* if this is a pseudo syscall (syscall < 0) then we need to
+		 * rewrite the syscall for some arch specific reason */
+		if (sc_tmp < 0) {
 			/* we set this as a strict op - we don't really care
 			 * since priorities are a "best effort" thing - as we
 			 * want to catch the -EDOM error and bail on this
@@ -1590,13 +1568,15 @@ int db_col_rule_add(struct db_filter_col *col,
 {
 	int rc = 0, rc_tmp;
 	unsigned int iter;
+	unsigned int chain_len;
 	unsigned int arg_num;
 	size_t chain_size;
 	struct db_api_arg *chain = NULL;
 	struct scmp_arg_cmp arg_data;
 
 	/* collect the arguments for the filter rule */
-	chain_size = sizeof(*chain) * ARG_COUNT_MAX;
+	chain_len = ARG_COUNT_MAX;
+	chain_size = sizeof(*chain) * chain_len;
 	chain = malloc(chain_size);
 	if (chain == NULL)
 		return -ENOMEM;
@@ -1604,7 +1584,7 @@ int db_col_rule_add(struct db_filter_col *col,
 	for (iter = 0; iter < arg_cnt; iter++) {
 		arg_data = arg_array[iter];
 		arg_num = arg_data.arg;
-		if (arg_num < ARG_COUNT_MAX && chain[arg_num].valid == 0) {
+		if (arg_num < chain_len && chain[arg_num].valid == 0) {
 			chain[arg_num].valid = 1;
 			chain[arg_num].arg = arg_num;
 			chain[arg_num].op = arg_data.op;
@@ -1636,7 +1616,8 @@ int db_col_rule_add(struct db_filter_col *col,
 
 	for (iter = 0; iter < col->filter_cnt; iter++) {
 		rc_tmp = arch_filter_rule_add(col, col->filters[iter], strict,
-					      action, syscall, chain);
+					      action, syscall,
+					      chain_len, chain);
 		if (rc == 0 && rc_tmp < 0)
 			rc = rc_tmp;
 	}
@@ -1658,6 +1639,7 @@ add_return:
 int db_col_transaction_start(struct db_filter_col *col)
 {
 	unsigned int iter;
+	size_t args_size;
 	struct db_filter_snap *snap;
 	struct db_filter *filter_o, *filter_s;
 	struct db_api_rule_list *rule_o, *rule_s;
@@ -1691,9 +1673,19 @@ int db_col_transaction_start(struct db_filter_col *col)
 			continue;
 		do {
 			/* copy the rule */
-			rule_s = db_rule_dup(rule_o);
+			rule_s = malloc(sizeof(*rule_s));
 			if (rule_s == NULL)
 				goto trans_start_failure;
+			args_size = sizeof(*rule_s->args) * rule_o->args_cnt;
+			rule_s->args = malloc(args_size);
+			if (rule_s->args == NULL) {
+				free(rule_s);
+				goto trans_start_failure;
+			}
+			rule_s->action = rule_o->action;
+			rule_s->syscall = rule_o->syscall;
+			rule_s->args_cnt = rule_o->args_cnt;
+			memcpy(rule_s->args, rule_o->args, args_size);
 			if (filter_s->rules != NULL) {
 				rule_s->prev = filter_s->rules->prev;
 				rule_s->next = filter_s->rules;
